A key indicator of climate change is the global mean temperature. Global mean temperature measures the change in temperature near the surface of the Earth and averaged across its surface. Increased concentrations of greenhouse gases in the atmosphere are the primary driver of the long-term increase in global mean temperature.

The Paris Agreement aims to hold the increase in the global average temperature to well below 2°C above pre-industrial levels and pursue efforts to limit the temperature increase to 1.5°C above pre-industrial levels, recognizing that this would significantly reduce the risks and impacts of climate change. The Paris Agreement is generally understood to refer to long-term changes in temperature, so a single year that exceeds 1.5°C would not necessarily signal a breach of the threshold.

Warming of the Earth is not the same everywhere. The land has warmed more rapidly than the ocean and the rate of warming has been highest in the Arctic, which has warmed around two to four times faster than the global mean depending on the time period chosen.

## What the IPCC says

A.1.2 Each of the last four decades has been successively warmer than any decade that preceded it since 1850. Global surface temperature in the first two decades of the 21st century (2001-2020) was 0.99 [0.84 to 1.10] °C higher than 1850-1900. Global surface temperature was 1.09 [0.95 to 1.20] °C higher in 2011-2020 than 1850-1900, with larger increases over land (1.59 [1.34 to 1.83] °C) than over the ocean (0.88 [0.68 to 1.01] °C). The estimated increase in global surface temperature since AR5 is principally due to further warming since 2003-2012 (+0.19 [0.16 to 0.22] °C). Additionally, methodological advances and new datasets contributed approximately 0.1°C to the updated estimate of warming in AR6.

A.1.3 The likely range of total human-caused global surface temperature increase from 1850-1900 to 2010-2019 is 0.8°C to 1.3°C, with a best estimate of 1.07°C. It is likely that well-mixed GHGs contributed a warming of 1.0°C to 2.0°C, other human drivers (principally aerosols) contributed a cooling of 0.0°C to 0.8°C, natural drivers changed global surface temperature by -0.1°C to +0.1°C, and internal variability changed it by -0.2°C to +0.2°C. It is very likely that well-mixed GHGs were the main driver of tropospheric warming since 1979 and extremely likely that human-caused stratospheric ozone depletion was the main driver of cooling of the lower stratosphere between 1979 and the mid-1990s.